==> sammaadmin-1.00.tar.gz: htdocs/admin/postldapadmin/samma/sender/index.php <==
<?php

/*
 * postLDAPadmin
 *
 * Copyright (C) 2006,2007 DesigNET, INC.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

/***********************************************************
 * ɥᥤ
 *
 * $RCSfile: index.php,v $
 * $Revision: 1.8 $
 * $Date: 2010/06/29 09:38:45 $
 **********************************************************/

include_once("../../initial");
include_once("lib/dglibpostldapadmin");
include_once("lib/dglibcommon");
include_once("lib/dglibpage");
include_once("lib/dglibsess");
include_once("lib/dglibldap");
include_once("lib/dglibsamma");

/********************************************************
ƥڡ
*********************************************************/

define("OPERATION",  "ɥᥤ");

/***********************************************************
 * 饹: ˥塼
 **********************************************************/
Class my_page extends page {

    /***********************************************************
     * ܥǥɽʥС饤ɡ
     **********************************************************/
    function display_body() {
        global $sesskey;

        print <<<EOD

<script type="text/javascript">
<!--
function sysSubmit(url, sender_name) {
    document.sender_list.action=url;
    document.sender_list.sender_name.value=sender_name;
    document.sender_list.submit();
}
// -->
</script>

<div>
  <b>
    ɥᥤȤǧ᡼륢ɥ쥹/ɥᥤΰǤ<br>
    SaMMAɥᥤʳΥ᡼Ź沽ޤ
  </b>
</div>
<br>
<form method="post" name="sender_list" action="index.php">
  <table class="table">
    <tbody>
      <tr>
        <td class="search_check"></td>
        <td class="search_name">ɥᥤ/᡼륢ɥ쥹</td>
        <td class="search_status">Ź沽롼</td>
        <td class="search_ref"></td>
      </tr>
EOD;

        /* ɽ */
        print_result();

        print <<<EOD
   </tbody>
  </table>
  <br>
  <input type="hidden" name="sender_name">
  <input type="hidden" name="sk" value="$sesskey">
  <input type="submit" name="new_add" value="" class="new_add_btn">
  <input type="submit" name="del" value="" class="check_del_btn" onClick="return msgConfirm('åɥᥤޤ\\nǤ')">
</form>
EOD;
    }
}

/*********************************************************
 * print_result
 *
 * ɽ
 *
 * []
 *       ʤ
 *
 * [֤]
 *       ʤ
 **********************************************************/
function print_result()
{
    global $db_data;
    global $del_list;
    global $sesskey;

    /* ǡ̵Ȥ϶ɽ */
    if (empty($db_data) === TRUE) {
        print "";
        return;
    }

    /* ǥȤ() */
    uksort($db_data, DOMAIN_SORT);

    /* ɥᥤ̾/᡼륢ɥ쥹ɽ */
    foreach($db_data as $key => $value) {

        /*  */
        $rule = DISP_EFFECT;
        $domain = $key;
        $checked = "";

        /* Ź沽롼 */
        $str = explode("!", $key, 2);
        if ($str[0] != $key) {
            $domain = $str[1];
            $rule = DISP_INEFFECT;
        }

        /* ݻ */
        if (is_array($del_list) === TRUE) {
            $ret = array_search($key, $del_list);
            if ($ret === FALSE) {
                $checked = "";
            } else {
                $checked = "checked";
            }
        }

        /*  */
        $domain = htmlspecialchars($domain);
        $cnv_key = str_replace("'", "\'", $key);

        print <<<EOD
      <tr>
        <td class="value">
          <input type="checkbox" name="delete[]" value="$key" $checked>
        </td>
        <td class="value">$domain</td>
        <td class="value_center">$rule</td>
        <td class="value_center">
          <input type="button" name="domain" class="list_mod_btn" onClick="sysSubmit('mod.php', '$cnv_key')" title="Խ">
        </td>
      </tr>
EOD;
    }

    return;
}

/***********************************************************
 * 
 **********************************************************/

/* 󥹥󥹺 */
$pg = new my_page();

/* ͤν */
$err_msg = "";
$del_list = "";

/* POSTϤäƤͤ */
if (isset($_POST["delete"]) === TRUE) {
    $del_list = $_POST["delete"];
}

/* ե롦ִեɹåå */
$ret = init();
if ($ret === FALSE) {
    $sys_err = TRUE;
    $pg->display(NULL);
    exit (1);
}

/* SaMMAեɹ */
$ret = read_samma_conf($web_conf["postldapadmin"]["sammaconf"]);
if ($ret === FALSE) {
    result_log(OPERATION . ":NG:" . $err_msg);
    $sys_err = TRUE;
    $pg->display(NULL);
    exit (1);
}

/***********************************************************
 * main
 **********************************************************/

/* DBեѥ */
$db_file = "";
if (isset($samma_conf["senderdb"]) === TRUE) {
    $files = explode(":", $samma_conf["senderdb"], 2);
    $db_file = $files[1];
} else {
    $err_msg = "DBե뤬ꤵƤޤ";
    result_log(OPERATION . ":NG:" . $err_msg);
    $sys_err = TRUE;
    $pg->display(CONTENT);
    exit (1);
}

/* Ͽܥ󤬲줿Ȥ */
if (isset($_POST["new_add"]) === TRUE) {

    /* ɥᥤɲò̤ */
    page_location("add.php", $del_list);
    exit (0);

/* ܥ󤬲줿Ȥ */
} elseif (isset($_POST["del"]) === TRUE) {

    /* ϥå*/
    if (is_array($del_list) === FALSE) {
        $err_msg = "оݤ򤵤Ƥޤ";
    } else { 
        /* ɥᥤ/᡼륢ɥ쥹κ */
        $ret = db_del($db_file, $del_list);
        if ($ret === FAIL) {
            result_log(OPERATION . ":NG:" . $err_msg);
            $sys_err = TRUE;
            $pg->display(NULL);
            exit (1);
        } elseif ($ret === FAIL_DEL) {
            $err_msg = "ɥᥤ" . $err_msg;
            result_log(OPERATION . ":NG:" . $err_msg);
            if ($suc_msg != "") {
                $suc_msg = "ɥᥤ" . $suc_msg;
                result_log(OPERATION . ":OK:" . $suc_msg);
                $err_msg .= "<br>" . $suc_msg;
            }
        } else {
            /* ｪλ */
            $err_msg = "ɥᥤ" . $suc_msg;
            result_log(OPERATION . ":OK:" . $err_msg);
        }
    }
}

/* ǡ١ */
$ret = db_search($db_file, $db_data);
if ($ret === FAIL) {
    result_log(OPERATION . ":NG:" . $err_msg);
    $sys_err = TRUE;
    $pg->display(NULL);
    exit (1);
}

/***********************************************************
 * ɽ
 **********************************************************/

$pg->display(CONTENT);
?>

==> sammaadmin-2.00.tar.gz: htdocs/admin/postldapadmin/samma/sender/index.php <==
<?php

/*
 * postLDAPadmin
 *
 * Copyright (C) 2006,2007 DesigNET, INC.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

/***********************************************************
 * ɥᥤ
 *
 * $RCSfile: index.php,v $
 * $Revision: 1.9 $
 * $Date: 2013/08/30 06:19:16 $
 **********************************************************/

include_once("../../initial");
include_once("lib/dglibpostldapadmin");
include_once("lib/dglibcommon");
include_once("lib/dglibpage");
include_once("lib/dglibsess");
include_once("lib/dglibldap");
include_once("lib/dglibsamma");

/********************************************************
ƥڡ
*********************************************************/

define("TMPLFILE", "samma/samma_admin_sender_menu.tmpl");
define("OPERATION",  "ɥᥤ");

/*********************************************************
 * print_result
 *
 * ɽ
 *
 * []
 *       ʤ
 *
 * [֤]
 *       ʤ
 **********************************************************/
function print_result(&$looptag)
{
    global $db_data;
    global $del_list;
    global $sesskey;

    /* ɥᥤ */
    $domain_count = 0;

    /* ǡ̵Ȥ϶ɽ */
    if (is_array($db_data) === FALSE) {
        $looptag = array();
        return;
    }

    /* ǥȤ() */
    uksort($db_data, DOMAIN_SORT);

    /* ɥᥤ̾/᡼륢ɥ쥹ɽ */
    foreach($db_data as $key => $value) {

        /*  */
        $rule = DISP_EFFECT;
        $domain = $key;
        $checked = "";

        /* Ź沽롼 */
        $str = explode("!", $key, 2);
        if ($str[0] != $key) {
            $domain = $str[1];
            $rule = DISP_INEFFECT;
        }

        /*  */
        $domain = htmlspecialchars($domain);
        $cnv_key = str_replace("'", "\'", $key);

        $looptag[$domain_count]["<<KEY>>"] = $key;
        $looptag[$domain_count]["<<DOMAIN>>"] = $domain;
        $looptag[$domain_count]["<<RULE>>"] = $rule;
        $looptag[$domain_count]["<<CNV_KEY>>"] = $cnv_key;

        $domain_count++;
    }

    return TRUE;
}

/***********************************************************
 * 
 **********************************************************/

/* ͤν */
$tag = array();
$looptag = array();
$err_msg = "";
$del_list = "";

/* POSTϤäƤͤ */
if (isset($_POST["delete"]) === TRUE) {
    $del_list = $_POST["delete"];
}

/* å󥭡ѿ */
if (isset ($_POST["sk"]) === TRUE) {
    $sesskey = $_POST["sk"];
}

/* ե롦ִեɹåå */
$ret = init();
if ($ret === FALSE) {
    syserr_display();
    exit (1);
}

/* SaMMAեɹ */
$ret = read_samma_conf($web_conf["postldapadmin"]["sammaconf"]);
if ($ret === FALSE) {
    result_log(OPERATION . ":NG:" . $err_msg);
    syserr_display();
    exit (1);
}

/***********************************************************
 * main
 **********************************************************/

/* DBեѥ */
$db_file = "";
if (isset($samma_conf["senderdb"]) === TRUE) {
    $files = explode(":", $samma_conf["senderdb"], 2);
    $db_file = $files[1];
} else {
    $err_msg = "DBե뤬ꤵƤޤ";
    result_log(OPERATION . ":NG:" . $err_msg);
    syserr_display();
    exit (1);
}

/* Ͽܥ󤬲줿Ȥ */
if (isset($_POST["new_add"]) === TRUE) {

    /* ɥᥤɲò̤ */
    dgp_location("add.php", $del_list);
    exit (0);

/* ܥ󤬲줿Ȥ */
} elseif (isset($_POST["del"]) === TRUE) {

    /* ϥå*/
    if (is_array($del_list) === FALSE) {
        $err_msg = "оݤ򤵤Ƥޤ";
    } else { 
        /* ɥᥤ/᡼륢ɥ쥹κ */
        $ret = db_del($db_file, $del_list);
        if ($ret === FAIL) {
            result_log(OPERATION . ":NG:" . $err_msg);
            syserr_display();
            exit (1);
        } elseif ($ret === FAIL_DEL) {
            $err_msg = "ɥᥤ" . $err_msg;
            result_log(OPERATION . ":NG:" . $err_msg);
            if ($suc_msg != "") {
                $suc_msg = "ɥᥤ" . $suc_msg;
                result_log(OPERATION . ":OK:" . $suc_msg);
                $err_msg .= "<br>" . $suc_msg;
            }
        } else {
            /* ｪλ */
            $err_msg = "ɥᥤ" . $suc_msg;
            result_log(OPERATION . ":OK:" . $err_msg);
        }
    }
}

/* ǡ١ */
$ret = db_search($db_file, $db_data);
if ($ret === FAIL) {
    result_log(OPERATION . ":NG:" . $err_msg);
    syserr_display();
    exit (1);
}

/***********************************************************
 * ɽ
 **********************************************************/
/* ̤Υ */
set_tag_common($tag);

/* ̤֤ */
print_result($looptag);

/* ڡν */
$ret = display(TMPLFILE, $tag, $looptag, STARTTAG, ENDTAG);
if ($ret === FALSE) {
    result_log($log_msg, LOG_ERR);
    syserr_display();
    exit(1);
}

?>
